Module: Dependabot::GithubActions::Lockfile::VersionGate

Extended by:
T::Sig
Defined in:
lib/dependabot/github_actions/lockfile/version_gate.rb

Overview

Pre-1.0 lockfile schema revisions may be breaking, so only the explicitly supported version is safe to read and rewrite.

Class Method Summary collapse

Class Method Details

.assert_supported!(found) ⇒ Object



18
19
20
21
22
# File 'lib/dependabot/github_actions/lockfile/version_gate.rb', line 18

def self.assert_supported!(found)
  return if compatible?(found)

  raise UnsupportedLockfileVersion.new(found, SUPPORTED_LOCKFILE_VERSION)
end

.compatible?(found) ⇒ Boolean

Returns:

  • (Boolean)


25
26
27
# File 'lib/dependabot/github_actions/lockfile/version_gate.rb', line 25

def self.compatible?(found)
  found == SUPPORTED_LOCKFILE_VERSION
end